import { useLanguage } from "@/contexts/LanguageContext";
import { motion } from "framer-motion";
import { Bot, ChevronRight } from "lucide-react";

export default function Hero() {
  const { language } = useLanguage();
  const isHebrew = language === "he";

  const content = {
    en: {
      badge: "AI-POWERED",
      title: "The revolution of Customers support",
      subtitle: "AI-powered automation is revolutionizing businesses worldwide. Those who adapt, lead. Those who don't, fall behind.",
      cta: "Get Started"
    },
    he: {
      badge: "אוטומציה עסקית",
      title: "מהפכת שירות הלקוחות",
      subtitle: "אוטומציה מבוססת בינה מלאכותית משדרגת עסקים בכל העולם. אלה שמסתגלים, מובילים. אלה שלא, נשארים מאחור.",
      cta: "להתחיל עכשיו"
    }
  };

  const selectedContent = isHebrew ? content.he : content.en;

  return (
    <section className="min-h-[90vh] relative flex items-center justify-center bg-[#030310]">
      {/* Tech grid background */}
      <div className="absolute inset-0 tech-grid opacity-5" />
      
      {/* Gradient overlays */}
      <div className="absolute inset-0 bg-gradient-radial from-purple-500/10 via-transparent to-transparent" />
      
      {/* Main content */}
      <div className="container relative z-10 px-4">
        <motion.div 
          initial={{ opacity: 0, y: 50 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.8 }}
          className="max-w-3xl mx-auto text-center"
        >
          {/* Badge */}
          <motion.div 
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6, delay: 0.2 }}
            className="inline-flex items-center gap-2 px-3 py-1.5 rounded-full bg-white/5 border border-purple-500/30 mb-8"
          >
            <Bot className="h-4 w-4 text-purple-400" />
            <span className="text-purple-200 text-sm">{selectedContent.badge}</span>
          </motion.div>

          {/* Title */}
          <motion.h1 
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6, delay: 0.4 }}
            className="text-4xl md:text-5xl lg:text-6xl font-bold mb-6 bg-clip-text text-transparent bg-gradient-to-r from-white via-purple-200 to-white leading-tight"
          >
            {selectedContent.title}
          </motion.h1>

          {/* Subtitle */}
          <motion.p 
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6, delay: 0.6 }}
            className="text-lg md:text-xl text-white/60 mb-12 max-w-2xl mx-auto"
          >
            {selectedContent.subtitle}
          </motion.p>

          {/* CTA Button */}
          <motion.button
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6, delay: 0.8 }}
            onClick={() => window.location.href = '#contact'}
            className="relative group inline-flex items-center gap-2 px-8 py-4 rounded-full bg-gradient-to-r from-purple-600 to-purple-800 hover:from-purple-500 hover:to-purple-700 text-white font-medium transition-all duration-300 hover:scale-105"
          >
            <span>{selectedContent.cta}</span>
            <ChevronRight className={`h-5 w-5 transition-transform group-hover:translate-x-1 ${isHebrew ? 'rotate-180' : ''}`} />
            <div className="absolute inset-0 rounded-full bg-gradient-to-r from-purple-600/50 to-purple-800/50 blur-xl opacity-0 group-hover:opacity-100 transition-opacity duration-300" />

          {/* Tech decoration */}
          <div className="absolute top-1/2 left-1/2 -translate-x-1/2 -translate-y-1/2 w-[200%] h-[200%] pointer-events-none">
            <div className="absolute inset-0 bg-[radial-gradient(circle_at_center,rgba(168,85,247,0.1),transparent_50%)]" />
          </div>
          </motion.button>
        </motion.div>
      </div>
    </section>
  );
}